# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Changed
- Migrated build system from setuptools to Hatch with hatch-vcs
- Added ruff for linting
- Added pre-commit hooks
- Added GitHub Actions for CI/CD

## [0.1.0] - 2025-01-20

### Added
- Initial release
- `diary-digest` command for generating digest summaries
- `diary-update` command for updating diary entries
- `diary-reconcile` command for reconciling entries
